@@ -176,7 +176,7 @@ class Ui_MainWindow(object):
     def showAbout(self):
         msgProgramName=" \nQuran Mobile for Nokia N900"
         msgAuthor="(c) Barakuba (aridho@gmail.com)\n "
-        msgVersion="Version 1.0\n "
+        msgVersion="Version 1.0.0\n "
         msg=msgProgramName+'\n'+msgAuthor+msgVersion
         QtGui.QMessageBox.information(None, 'About',msg, QtGui.QMessageBox.Close)
 
@@ -192,10 +192,10 @@ class Ui_MainWindow(object):
     def savePage(self):
         s=str(self.page)
 
-	f = open('/home/user/MyDocs/.documents/quran/quran_track.ptr', "w")
+	f = open('quran_track.ptr', "w")
         f.write(s)
         f.close()
-        QtGui.QMessageBox.information(None, 'Save','Page already saved', QtGui.QMessageBox.Close)
+        QtGui.QMessageBox.information(None, 'Save','This page is already saved', QtGui.QMessageBox.Close)
         self.FullView.setFocus()
 
 
